# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_hand/rhactionsmessages_win.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_hand/rhactionsmessages_win.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n(com.exactpro.th2.act.grpc.hand.rhactionsB\024RhWinActionsMessagesP\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)th2_grpc_hand/rhactionsmessages_win.proto\x1a\x1egoogle/protobuf/wrappers.proto\"a\n\nWinLocator\x12\x0f\n\x07locator\x18\x01 \x01(\t\x12\x0f\n\x07matcher\x18\x02 \x01(\t\x12\x31\n\x0cmatcherIndex\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"Z\n\rBaseWinParams\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x02 \x01(\t\x12\x10\n\x08\x66romRoot\x18\x03 \x01(\x08\x12\x1a\n\x12\x65xperimentalDriver\x18\x04 \x01(\x08\"`\n\x07WinOpen\x12\x0f\n\x07workDir\x18\x04 \x01(\t\x12\x0f\n\x07\x61ppFile\x18\x05 \x01(\t\x12\x0f\n\x07\x61ppArgs\x18\x06 \x01(\t\x12\"\n\nbaseParams\x18\x07 \x01(\x0b\x32\x0e.BaseWinParams\"\xb7\x02\n\x08WinClick\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12 \n\x06\x62utton\x18\x04 \x01(\x0e\x32\x10.WinClick.Button\x12\x0f\n\x07xOffset\x18\x05 \x01(\t\x12\x0f\n\x07yOffset\x18\x06 \x01(\t\x12\"\n\nbaseParams\x18\x08 \x01(\x0b\x32\x0e.BaseWinParams\x12\x11\n\tmodifiers\x18\t \x01(\t\"5\n\x06\x42utton\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01\x12\n\n\x06MIDDLE\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\"Z\n\x0e\x41ttachedBorder\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08LEFT_TOP\x10\x01\x12\x0f\n\x0bLEFT_BOTTOM\x10\x02\x12\r\n\tRIGHT_TOP\x10\x03\x12\x10\n\x0cRIGHT_BOTTOM\x10\x04\"\x89\x01\n\x0bWinSendText\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x13\n\x0b\x63learBefore\x18\x05 \x01(\t\x12\x14\n\x0cisDirectText\x18\x06 \x01(\t\x12\"\n\nbaseParams\x18\x07 \x01(\x0b\x32\x0e.BaseWinParams\"y\n\x12WinGetActiveWindow\x12\x12\n\nwindowName\x18\x04 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65ssibilityId\x18\x05 \x01(\t\x12\x12\n\nmaxTimeout\x18\x06 \x01(\x05\x12\"\n\nbaseParams\x18\x07 \x01(\x0b\x32\x0e.BaseWinParams\"8\n\x12MaximizeMainWindow\x12\"\n\nbaseParams\x18\x04 \x01(\x0b\x32\x0e.BaseWinParams\"r\n\x16WinGetElementAttribute\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x15\n\rattributeName\x18\x04 \x01(\t\x12\"\n\nbaseParams\x18\x05 \x01(\x0b\x32\x0e.BaseWinParams\"=\n\x07WinWait\x12\x0e\n\x06millis\x18\x04 \x01(\r\x12\"\n\nbaseParams\x18\x05 \x01(\x0b\x32\x0e.BaseWinParams\"m\n\x11WinToggleCheckBox\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x15\n\rexpectedState\x18\x04 \x01(\t\x12\"\n\nbaseParams\x18\x05 \x01(\x0b\x32\x0e.BaseWinParams\"i\n\x0fWinCheckElement\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\"\n\nbaseParams\x18\x04 \x01(\x0b\x32\x0e.BaseWinParams\x12\x13\n\x0bsaveElement\x18\x05 \x01(\x08\"_\n\x0cWinGetWindow\x12\x12\n\nwindowName\x18\x04 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65ssibilityId\x18\x05 \x01(\t\x12\"\n\nbaseParams\x18\x06 \x01(\x0b\x32\x0e.BaseWinParams\"o\n\x10WinSearchElement\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\"\n\nbaseParams\x18\x04 \x01(\x0b\x32\x0e.BaseWinParams\x12\x18\n\x10multipleElements\x18\x05 \x01(\x08\"\xb1\x01\n\x13WinWaitForAttribute\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x15\n\rattributeName\x18\x04 \x01(\t\x12\x15\n\rexpectedValue\x18\x05 \x01(\t\x12\x12\n\nmaxTimeout\x18\x06 \x01(\t\x12\x15\n\rcheckInterval\x18\x07 \x01(\t\x12\"\n\nbaseParams\x18\t \x01(\x0b\x32\x0e.BaseWinParams\"\xa5\x01\n\x12WinScrollUsingText\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x12\n\ntextToSend\x18\x04 \x01(\t\x12\x15\n\rmaxIterations\x18\x05 \x01(\t\x12!\n\x0ctextLocators\x18\x06 \x03(\x0b\x32\x0b.WinLocator\x12\"\n\nbaseParams\x18\x07 \x01(\x0b\x32\x0e.BaseWinParams\"=\n\x17WinGetDataFromClipboard\x12\"\n\nbaseParams\x18\x04 \x01(\x0b\x32\x0e.BaseWinParams\"\x97\x01\n\rWinTableClick\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x14\n\x0csearchParams\x18\x04 \x01(\t\x12\x14\n\x0ctargetColumn\x18\x05 \x01(\t\x12\x13\n\x0b\x63olumnIndex\x18\x06 \x01(\t\x12\"\n\nbaseParams\x18\x07 \x01(\x0b\x32\x0e.BaseWinParams:\x02\x18\x01\"\x93\x02\n\x0eWinTableSearch\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x14\n\x0csearchParams\x18\x04 \x01(\t\x12\x14\n\x0ctargetColumn\x18\x05 \x01(\t\x12\x13\n\x0b\x63olumnIndex\x18\x06 \x01(\t\x12\x15\n\rfirstRowIndex\x18\x07 \x01(\t\x12\x15\n\rrowNameFormat\x18\x08 \x01(\t\x12\x1c\n\x14rowElementNameFormat\x18\t \x01(\t\x12\x1d\n\x15rowElementValueFormat\x18\n \x01(\t\x12\x12\n\nsaveResult\x18\x0b \x01(\t\x12\"\n\nbaseParams\x18\x0c \x01(\x0b\x32\x0e.BaseWinParams\"g\n\x11WinWaitForElement\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x0f\n\x07timeout\x18\x04 \x01(\t\x12\"\n\nbaseParams\x18\x06 \x01(\x0b\x32\x0e.BaseWinParams\"U\n\x10WinGetScreenshot\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\"\n\nbaseParams\x18\x04 \x01(\x0b\x32\x0e.BaseWinParams\"6\n\x10WinRestartDriver\x12\"\n\nbaseParams\x18\x01 \x01(\x0b\x32\x0e.BaseWinParams\"y\n\x12WinGetElementColor\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x0f\n\x07xOffset\x18\x04 \x01(\t\x12\x0f\n\x07yOffset\x18\x05 \x01(\t\x12\"\n\nbaseParams\x18\x06 \x01(\x0b\x32\x0e.BaseWinParams\"\xc8\x01\n\x0eWinDragAndDrop\x12!\n\x0c\x66romLocators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\x1f\n\ntoLocators\x18\x02 \x03(\x0b\x32\x0b.WinLocator\x12\x13\n\x0b\x66romOffsetX\x18\x06 \x01(\t\x12\x13\n\x0b\x66romOffsetY\x18\x07 \x01(\t\x12\x11\n\ttoOffsetX\x18\x08 \x01(\t\x12\x11\n\ttoOffsetY\x18\t \x01(\t\x12\"\n\nbaseParams\x18\n \x01(\x0b\x32\x0e.BaseWinParams\"\xee\x02\n\x12WinScrollToElement\x12$\n\x0f\x65lementLocators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12#\n\x0e\x61\x63tionLocators\x18\x02 \x03(\x0b\x32\x0b.WinLocator\x12\x17\n\x0fisElementInTree\x18\x05 \x01(\x08\x12\"\n\x1aisElementShouldBeDisplayed\x18\x06 \x01(\x08\x12\x32\n\nscrollType\x18\x07 \x01(\x0e\x32\x1e.WinScrollToElement.ScrollType\x12\x15\n\rmaxIterations\x18\x08 \x01(\x05\x12\x14\n\x0c\x63lickOffsetX\x18\t \x01(\t\x12\x14\n\x0c\x63lickOffsetY\x18\n \x01(\t\x12\x12\n\ntextToSend\x18\x0b \x01(\t\x12\"\n\nbaseParams\x18\x0c \x01(\x0b\x32\x0e.BaseWinParams\"!\n\nScrollType\x12\t\n\x05\x43LICK\x10\x00\x12\x08\n\x04TEXT\x10\x01\"\x8c\x01\n\x12WinColorsCollector\x12\"\n\nbaseParams\x18\x01 \x01(\x0b\x32\x0e.BaseWinParams\x12\x14\n\x0cstartXOffset\x18\x02 \x01(\t\x12\x14\n\x0cstartYOffset\x18\x03 \x01(\t\x12\x12\n\nendXOffset\x18\x04 \x01(\t\x12\x12\n\nendYOffset\x18\x05 \x01(\tBB\n(com.exactpro.th2.act.grpc.hand.rhactionsB\x14RhWinActionsMessagesP\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])



_WINCLICK_BUTTON = _descriptor.EnumDescriptor(
  name='Button',
  full_name='WinClick.Button',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIDDLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=533,
  serialized_end=586,
)
_sym_db.RegisterEnumDescriptor(_WINCLICK_BUTTON)

_WINCLICK_ATTACHEDBORDER = _descriptor.EnumDescriptor(
  name='AttachedBorder',
  full_name='WinClick.AttachedBorder',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_BOTTOM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_BOTTOM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=588,
  serialized_end=678,
)
_sym_db.RegisterEnumDescriptor(_WINCLICK_ATTACHEDBORDER)

_WINSCROLLTOELEMENT_SCROLLTYPE = _descriptor.EnumDescriptor(
  name='ScrollType',
  full_name='WinScrollToElement.ScrollType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLICK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3359,
  serialized_end=3392,
)
_sym_db.RegisterEnumDescriptor(_WINSCROLLTOELEMENT_SCROLLTYPE)


_WINLOCATOR = _descriptor.Descriptor(
  name='WinLocator',
  full_name='WinLocator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locator', full_name='WinLocator.locator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='WinLocator.matcher', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcherIndex', full_name='WinLocator.matcherIndex', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=174,
)


_BASEWINPARAMS = _descriptor.Descriptor(
  name='BaseWinParams',
  full_name='BaseWinParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='BaseWinParams.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='BaseWinParams.execute', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromRoot', full_name='BaseWinParams.fromRoot', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experimentalDriver', full_name='BaseWinParams.experimentalDriver', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=266,
)


_WINOPEN = _descriptor.Descriptor(
  name='WinOpen',
  full_name='WinOpen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workDir', full_name='WinOpen.workDir', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appFile', full_name='WinOpen.appFile', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appArgs', full_name='WinOpen.appArgs', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinOpen.baseParams', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=364,
)


_WINCLICK = _descriptor.Descriptor(
  name='WinClick',
  full_name='WinClick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinClick.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='WinClick.button', index=1,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xOffset', full_name='WinClick.xOffset', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yOffset', full_name='WinClick.yOffset', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinClick.baseParams', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modifiers', full_name='WinClick.modifiers', index=5,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WINCLICK_BUTTON,
    _WINCLICK_ATTACHEDBORDER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=678,
)


_WINSENDTEXT = _descriptor.Descriptor(
  name='WinSendText',
  full_name='WinSendText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinSendText.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='WinSendText.text', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clearBefore', full_name='WinSendText.clearBefore', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isDirectText', full_name='WinSendText.isDirectText', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinSendText.baseParams', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=818,
)


_WINGETACTIVEWINDOW = _descriptor.Descriptor(
  name='WinGetActiveWindow',
  full_name='WinGetActiveWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='windowName', full_name='WinGetActiveWindow.windowName', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accessibilityId', full_name='WinGetActiveWindow.accessibilityId', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxTimeout', full_name='WinGetActiveWindow.maxTimeout', index=2,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinGetActiveWindow.baseParams', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=820,
  serialized_end=941,
)


_MAXIMIZEMAINWINDOW = _descriptor.Descriptor(
  name='MaximizeMainWindow',
  full_name='MaximizeMainWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='MaximizeMainWindow.baseParams', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=999,
)


_WINGETELEMENTATTRIBUTE = _descriptor.Descriptor(
  name='WinGetElementAttribute',
  full_name='WinGetElementAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinGetElementAttribute.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributeName', full_name='WinGetElementAttribute.attributeName', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinGetElementAttribute.baseParams', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1001,
  serialized_end=1115,
)


_WINWAIT = _descriptor.Descriptor(
  name='WinWait',
  full_name='WinWait',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='millis', full_name='WinWait.millis', index=0,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinWait.baseParams', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1117,
  serialized_end=1178,
)


_WINTOGGLECHECKBOX = _descriptor.Descriptor(
  name='WinToggleCheckBox',
  full_name='WinToggleCheckBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinToggleCheckBox.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expectedState', full_name='WinToggleCheckBox.expectedState', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinToggleCheckBox.baseParams', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1289,
)


_WINCHECKELEMENT = _descriptor.Descriptor(
  name='WinCheckElement',
  full_name='WinCheckElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinCheckElement.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinCheckElement.baseParams', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saveElement', full_name='WinCheckElement.saveElement', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1291,
  serialized_end=1396,
)


_WINGETWINDOW = _descriptor.Descriptor(
  name='WinGetWindow',
  full_name='WinGetWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='windowName', full_name='WinGetWindow.windowName', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accessibilityId', full_name='WinGetWindow.accessibilityId', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinGetWindow.baseParams', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1398,
  serialized_end=1493,
)


_WINSEARCHELEMENT = _descriptor.Descriptor(
  name='WinSearchElement',
  full_name='WinSearchElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinSearchElement.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinSearchElement.baseParams', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multipleElements', full_name='WinSearchElement.multipleElements', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1606,
)


_WINWAITFORATTRIBUTE = _descriptor.Descriptor(
  name='WinWaitForAttribute',
  full_name='WinWaitForAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinWaitForAttribute.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributeName', full_name='WinWaitForAttribute.attributeName', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expectedValue', full_name='WinWaitForAttribute.expectedValue', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxTimeout', full_name='WinWaitForAttribute.maxTimeout', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkInterval', full_name='WinWaitForAttribute.checkInterval', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinWaitForAttribute.baseParams', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1609,
  serialized_end=1786,
)


_WINSCROLLUSINGTEXT = _descriptor.Descriptor(
  name='WinScrollUsingText',
  full_name='WinScrollUsingText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinScrollUsingText.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='textToSend', full_name='WinScrollUsingText.textToSend', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxIterations', full_name='WinScrollUsingText.maxIterations', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='textLocators', full_name='WinScrollUsingText.textLocators', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinScrollUsingText.baseParams', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1789,
  serialized_end=1954,
)


_WINGETDATAFROMCLIPBOARD = _descriptor.Descriptor(
  name='WinGetDataFromClipboard',
  full_name='WinGetDataFromClipboard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinGetDataFromClipboard.baseParams', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1956,
  serialized_end=2017,
)


_WINTABLECLICK = _descriptor.Descriptor(
  name='WinTableClick',
  full_name='WinTableClick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinTableClick.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchParams', full_name='WinTableClick.searchParams', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetColumn', full_name='WinTableClick.targetColumn', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columnIndex', full_name='WinTableClick.columnIndex', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinTableClick.baseParams', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\030\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2020,
  serialized_end=2171,
)


_WINTABLESEARCH = _descriptor.Descriptor(
  name='WinTableSearch',
  full_name='WinTableSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinTableSearch.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchParams', full_name='WinTableSearch.searchParams', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetColumn', full_name='WinTableSearch.targetColumn', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columnIndex', full_name='WinTableSearch.columnIndex', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firstRowIndex', full_name='WinTableSearch.firstRowIndex', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rowNameFormat', full_name='WinTableSearch.rowNameFormat', index=5,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rowElementNameFormat', full_name='WinTableSearch.rowElementNameFormat', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rowElementValueFormat', full_name='WinTableSearch.rowElementValueFormat', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saveResult', full_name='WinTableSearch.saveResult', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinTableSearch.baseParams', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2449,
)


_WINWAITFORELEMENT = _descriptor.Descriptor(
  name='WinWaitForElement',
  full_name='WinWaitForElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinWaitForElement.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='WinWaitForElement.timeout', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinWaitForElement.baseParams', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2451,
  serialized_end=2554,
)


_WINGETSCREENSHOT = _descriptor.Descriptor(
  name='WinGetScreenshot',
  full_name='WinGetScreenshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinGetScreenshot.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinGetScreenshot.baseParams', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2556,
  serialized_end=2641,
)


_WINRESTARTDRIVER = _descriptor.Descriptor(
  name='WinRestartDriver',
  full_name='WinRestartDriver',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinRestartDriver.baseParams', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2643,
  serialized_end=2697,
)


_WINGETELEMENTCOLOR = _descriptor.Descriptor(
  name='WinGetElementColor',
  full_name='WinGetElementColor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinGetElementColor.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xOffset', full_name='WinGetElementColor.xOffset', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yOffset', full_name='WinGetElementColor.yOffset', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinGetElementColor.baseParams', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2699,
  serialized_end=2820,
)


_WINDRAGANDDROP = _descriptor.Descriptor(
  name='WinDragAndDrop',
  full_name='WinDragAndDrop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fromLocators', full_name='WinDragAndDrop.fromLocators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toLocators', full_name='WinDragAndDrop.toLocators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromOffsetX', full_name='WinDragAndDrop.fromOffsetX', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromOffsetY', full_name='WinDragAndDrop.fromOffsetY', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toOffsetX', full_name='WinDragAndDrop.toOffsetX', index=4,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toOffsetY', full_name='WinDragAndDrop.toOffsetY', index=5,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinDragAndDrop.baseParams', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2823,
  serialized_end=3023,
)


_WINSCROLLTOELEMENT = _descriptor.Descriptor(
  name='WinScrollToElement',
  full_name='WinScrollToElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elementLocators', full_name='WinScrollToElement.elementLocators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actionLocators', full_name='WinScrollToElement.actionLocators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isElementInTree', full_name='WinScrollToElement.isElementInTree', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isElementShouldBeDisplayed', full_name='WinScrollToElement.isElementShouldBeDisplayed', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scrollType', full_name='WinScrollToElement.scrollType', index=4,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxIterations', full_name='WinScrollToElement.maxIterations', index=5,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clickOffsetX', full_name='WinScrollToElement.clickOffsetX', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clickOffsetY', full_name='WinScrollToElement.clickOffsetY', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='textToSend', full_name='WinScrollToElement.textToSend', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinScrollToElement.baseParams', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WINSCROLLTOELEMENT_SCROLLTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3026,
  serialized_end=3392,
)


_WINCOLORSCOLLECTOR = _descriptor.Descriptor(
  name='WinColorsCollector',
  full_name='WinColorsCollector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='baseParams', full_name='WinColorsCollector.baseParams', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startXOffset', full_name='WinColorsCollector.startXOffset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startYOffset', full_name='WinColorsCollector.startYOffset', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endXOffset', full_name='WinColorsCollector.endXOffset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endYOffset', full_name='WinColorsCollector.endYOffset', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3395,
  serialized_end=3535,
)

_WINLOCATOR.fields_by_name['matcherIndex'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_WINOPEN.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINCLICK.fields_by_name['locators'].message_type = _WINLOCATOR
_WINCLICK.fields_by_name['button'].enum_type = _WINCLICK_BUTTON
_WINCLICK.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINCLICK_BUTTON.containing_type = _WINCLICK
_WINCLICK_ATTACHEDBORDER.containing_type = _WINCLICK
_WINSENDTEXT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINSENDTEXT.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINGETACTIVEWINDOW.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_MAXIMIZEMAINWINDOW.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINGETELEMENTATTRIBUTE.fields_by_name['locators'].message_type = _WINLOCATOR
_WINGETELEMENTATTRIBUTE.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINWAIT.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINTOGGLECHECKBOX.fields_by_name['locators'].message_type = _WINLOCATOR
_WINTOGGLECHECKBOX.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINCHECKELEMENT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINCHECKELEMENT.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINGETWINDOW.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINSEARCHELEMENT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINSEARCHELEMENT.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINWAITFORATTRIBUTE.fields_by_name['locators'].message_type = _WINLOCATOR
_WINWAITFORATTRIBUTE.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINSCROLLUSINGTEXT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINSCROLLUSINGTEXT.fields_by_name['textLocators'].message_type = _WINLOCATOR
_WINSCROLLUSINGTEXT.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINGETDATAFROMCLIPBOARD.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINTABLECLICK.fields_by_name['locators'].message_type = _WINLOCATOR
_WINTABLECLICK.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINTABLESEARCH.fields_by_name['locators'].message_type = _WINLOCATOR
_WINTABLESEARCH.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINWAITFORELEMENT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINWAITFORELEMENT.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINGETSCREENSHOT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINGETSCREENSHOT.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINRESTARTDRIVER.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINGETELEMENTCOLOR.fields_by_name['locators'].message_type = _WINLOCATOR
_WINGETELEMENTCOLOR.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINDRAGANDDROP.fields_by_name['fromLocators'].message_type = _WINLOCATOR
_WINDRAGANDDROP.fields_by_name['toLocators'].message_type = _WINLOCATOR
_WINDRAGANDDROP.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINSCROLLTOELEMENT.fields_by_name['elementLocators'].message_type = _WINLOCATOR
_WINSCROLLTOELEMENT.fields_by_name['actionLocators'].message_type = _WINLOCATOR
_WINSCROLLTOELEMENT.fields_by_name['scrollType'].enum_type = _WINSCROLLTOELEMENT_SCROLLTYPE
_WINSCROLLTOELEMENT.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
_WINSCROLLTOELEMENT_SCROLLTYPE.containing_type = _WINSCROLLTOELEMENT
_WINCOLORSCOLLECTOR.fields_by_name['baseParams'].message_type = _BASEWINPARAMS
DESCRIPTOR.message_types_by_name['WinLocator'] = _WINLOCATOR
DESCRIPTOR.message_types_by_name['BaseWinParams'] = _BASEWINPARAMS
DESCRIPTOR.message_types_by_name['WinOpen'] = _WINOPEN
DESCRIPTOR.message_types_by_name['WinClick'] = _WINCLICK
DESCRIPTOR.message_types_by_name['WinSendText'] = _WINSENDTEXT
DESCRIPTOR.message_types_by_name['WinGetActiveWindow'] = _WINGETACTIVEWINDOW
DESCRIPTOR.message_types_by_name['MaximizeMainWindow'] = _MAXIMIZEMAINWINDOW
DESCRIPTOR.message_types_by_name['WinGetElementAttribute'] = _WINGETELEMENTATTRIBUTE
DESCRIPTOR.message_types_by_name['WinWait'] = _WINWAIT
DESCRIPTOR.message_types_by_name['WinToggleCheckBox'] = _WINTOGGLECHECKBOX
DESCRIPTOR.message_types_by_name['WinCheckElement'] = _WINCHECKELEMENT
DESCRIPTOR.message_types_by_name['WinGetWindow'] = _WINGETWINDOW
DESCRIPTOR.message_types_by_name['WinSearchElement'] = _WINSEARCHELEMENT
DESCRIPTOR.message_types_by_name['WinWaitForAttribute'] = _WINWAITFORATTRIBUTE
DESCRIPTOR.message_types_by_name['WinScrollUsingText'] = _WINSCROLLUSINGTEXT
DESCRIPTOR.message_types_by_name['WinGetDataFromClipboard'] = _WINGETDATAFROMCLIPBOARD
DESCRIPTOR.message_types_by_name['WinTableClick'] = _WINTABLECLICK
DESCRIPTOR.message_types_by_name['WinTableSearch'] = _WINTABLESEARCH
DESCRIPTOR.message_types_by_name['WinWaitForElement'] = _WINWAITFORELEMENT
DESCRIPTOR.message_types_by_name['WinGetScreenshot'] = _WINGETSCREENSHOT
DESCRIPTOR.message_types_by_name['WinRestartDriver'] = _WINRESTARTDRIVER
DESCRIPTOR.message_types_by_name['WinGetElementColor'] = _WINGETELEMENTCOLOR
DESCRIPTOR.message_types_by_name['WinDragAndDrop'] = _WINDRAGANDDROP
DESCRIPTOR.message_types_by_name['WinScrollToElement'] = _WINSCROLLTOELEMENT
DESCRIPTOR.message_types_by_name['WinColorsCollector'] = _WINCOLORSCOLLECTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WinLocator = _reflection.GeneratedProtocolMessageType('WinLocator', (_message.Message,), {
  'DESCRIPTOR' : _WINLOCATOR,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinLocator)
  })
_sym_db.RegisterMessage(WinLocator)

BaseWinParams = _reflection.GeneratedProtocolMessageType('BaseWinParams', (_message.Message,), {
  'DESCRIPTOR' : _BASEWINPARAMS,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:BaseWinParams)
  })
_sym_db.RegisterMessage(BaseWinParams)

WinOpen = _reflection.GeneratedProtocolMessageType('WinOpen', (_message.Message,), {
  'DESCRIPTOR' : _WINOPEN,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinOpen)
  })
_sym_db.RegisterMessage(WinOpen)

WinClick = _reflection.GeneratedProtocolMessageType('WinClick', (_message.Message,), {
  'DESCRIPTOR' : _WINCLICK,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinClick)
  })
_sym_db.RegisterMessage(WinClick)

WinSendText = _reflection.GeneratedProtocolMessageType('WinSendText', (_message.Message,), {
  'DESCRIPTOR' : _WINSENDTEXT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinSendText)
  })
_sym_db.RegisterMessage(WinSendText)

WinGetActiveWindow = _reflection.GeneratedProtocolMessageType('WinGetActiveWindow', (_message.Message,), {
  'DESCRIPTOR' : _WINGETACTIVEWINDOW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetActiveWindow)
  })
_sym_db.RegisterMessage(WinGetActiveWindow)

MaximizeMainWindow = _reflection.GeneratedProtocolMessageType('MaximizeMainWindow', (_message.Message,), {
  'DESCRIPTOR' : _MAXIMIZEMAINWINDOW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:MaximizeMainWindow)
  })
_sym_db.RegisterMessage(MaximizeMainWindow)

WinGetElementAttribute = _reflection.GeneratedProtocolMessageType('WinGetElementAttribute', (_message.Message,), {
  'DESCRIPTOR' : _WINGETELEMENTATTRIBUTE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetElementAttribute)
  })
_sym_db.RegisterMessage(WinGetElementAttribute)

WinWait = _reflection.GeneratedProtocolMessageType('WinWait', (_message.Message,), {
  'DESCRIPTOR' : _WINWAIT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinWait)
  })
_sym_db.RegisterMessage(WinWait)

WinToggleCheckBox = _reflection.GeneratedProtocolMessageType('WinToggleCheckBox', (_message.Message,), {
  'DESCRIPTOR' : _WINTOGGLECHECKBOX,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinToggleCheckBox)
  })
_sym_db.RegisterMessage(WinToggleCheckBox)

WinCheckElement = _reflection.GeneratedProtocolMessageType('WinCheckElement', (_message.Message,), {
  'DESCRIPTOR' : _WINCHECKELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinCheckElement)
  })
_sym_db.RegisterMessage(WinCheckElement)

WinGetWindow = _reflection.GeneratedProtocolMessageType('WinGetWindow', (_message.Message,), {
  'DESCRIPTOR' : _WINGETWINDOW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetWindow)
  })
_sym_db.RegisterMessage(WinGetWindow)

WinSearchElement = _reflection.GeneratedProtocolMessageType('WinSearchElement', (_message.Message,), {
  'DESCRIPTOR' : _WINSEARCHELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinSearchElement)
  })
_sym_db.RegisterMessage(WinSearchElement)

WinWaitForAttribute = _reflection.GeneratedProtocolMessageType('WinWaitForAttribute', (_message.Message,), {
  'DESCRIPTOR' : _WINWAITFORATTRIBUTE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinWaitForAttribute)
  })
_sym_db.RegisterMessage(WinWaitForAttribute)

WinScrollUsingText = _reflection.GeneratedProtocolMessageType('WinScrollUsingText', (_message.Message,), {
  'DESCRIPTOR' : _WINSCROLLUSINGTEXT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinScrollUsingText)
  })
_sym_db.RegisterMessage(WinScrollUsingText)

WinGetDataFromClipboard = _reflection.GeneratedProtocolMessageType('WinGetDataFromClipboard', (_message.Message,), {
  'DESCRIPTOR' : _WINGETDATAFROMCLIPBOARD,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetDataFromClipboard)
  })
_sym_db.RegisterMessage(WinGetDataFromClipboard)

WinTableClick = _reflection.GeneratedProtocolMessageType('WinTableClick', (_message.Message,), {
  'DESCRIPTOR' : _WINTABLECLICK,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinTableClick)
  })
_sym_db.RegisterMessage(WinTableClick)

WinTableSearch = _reflection.GeneratedProtocolMessageType('WinTableSearch', (_message.Message,), {
  'DESCRIPTOR' : _WINTABLESEARCH,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinTableSearch)
  })
_sym_db.RegisterMessage(WinTableSearch)

WinWaitForElement = _reflection.GeneratedProtocolMessageType('WinWaitForElement', (_message.Message,), {
  'DESCRIPTOR' : _WINWAITFORELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinWaitForElement)
  })
_sym_db.RegisterMessage(WinWaitForElement)

WinGetScreenshot = _reflection.GeneratedProtocolMessageType('WinGetScreenshot', (_message.Message,), {
  'DESCRIPTOR' : _WINGETSCREENSHOT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetScreenshot)
  })
_sym_db.RegisterMessage(WinGetScreenshot)

WinRestartDriver = _reflection.GeneratedProtocolMessageType('WinRestartDriver', (_message.Message,), {
  'DESCRIPTOR' : _WINRESTARTDRIVER,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinRestartDriver)
  })
_sym_db.RegisterMessage(WinRestartDriver)

WinGetElementColor = _reflection.GeneratedProtocolMessageType('WinGetElementColor', (_message.Message,), {
  'DESCRIPTOR' : _WINGETELEMENTCOLOR,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetElementColor)
  })
_sym_db.RegisterMessage(WinGetElementColor)

WinDragAndDrop = _reflection.GeneratedProtocolMessageType('WinDragAndDrop', (_message.Message,), {
  'DESCRIPTOR' : _WINDRAGANDDROP,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinDragAndDrop)
  })
_sym_db.RegisterMessage(WinDragAndDrop)

WinScrollToElement = _reflection.GeneratedProtocolMessageType('WinScrollToElement', (_message.Message,), {
  'DESCRIPTOR' : _WINSCROLLTOELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinScrollToElement)
  })
_sym_db.RegisterMessage(WinScrollToElement)

WinColorsCollector = _reflection.GeneratedProtocolMessageType('WinColorsCollector', (_message.Message,), {
  'DESCRIPTOR' : _WINCOLORSCOLLECTOR,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinColorsCollector)
  })
_sym_db.RegisterMessage(WinColorsCollector)


DESCRIPTOR._options = None
_WINTABLECLICK._options = None
# @@protoc_insertion_point(module_scope)
